Rest API
========

.. image:: ../../../tests/robotframework/screenshots/swagger.png
   :class: sosse-screenshot

A rest API is available, it can be explored with a `Swagger <https://swagger.io/>`_ user interface. To open it, click the |user_menu_button| button, then select ``Rest API``.

.. |user_menu_button| image:: ../../../tests/robotframework/screenshots/user_menu_button.png
   :class: sosse-inline-screenshot
